@@ -15,7 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
-from os import path
+import subprocess
 from PyQt5 import QtCore, QtWidgets, QtGui
 import gpxviewer.plotviewer as plt
 import gpxviewer.gpxmodel as gpx
@@ -62,7 +62,7 @@ class GpxMainWindow(QtWidgets.QMainWindow):
     self.filterLineEdit.setPlaceholderText(self.tr('Enter regular expression'))
     self.filterLineEdit.setClearButtonEnabled(True)
     wdg.layout().addWidget(self.filterLineEdit)
-    self.ui.secondaryToolBar.addWidget(wdg)
+    self.ui.filterToolBar.addWidget(wdg)
 
     self.includefiltermodel = QtCore.QSortFilterProxyModel(self)
     self.includefiltermodel.setSourceModel(TheDocument.wptmodel)
@@ -92,6 +92,7 @@ class GpxMainWindow(QtWidgets.QMainWindow):
     self.resize(TheConfig['MainWindow'].getint('WindowWidth'), TheConfig['MainWindow'].getint('WindowHeight'))
 
     TheDocument.gpxparser.warningSent.connect(self.showWarning)
+    TheDocument.gpxparser.wptmodel.namesChanged.connect(self.setProjectChanged)
 
     self.projectSaved = False
     self.projectChanged = False
@@ -102,6 +103,19 @@ class GpxMainWindow(QtWidgets.QMainWindow):
   def aboutQt(self):
     QtWidgets.QApplication.aboutQt()
 
+  def eventFilter(self, obj, event):
+    if event.type() == QtCore.QEvent.KeyPress and event.key() == QtCore.Qt.Key_Tab and event.modifiers() == QtCore.Qt.ControlModifier:
+      self.keyPressEvent(QtGui.QKeyEvent(event))
+      return True
+    elif event.type() == QtCore.QEvent.ContextMenu or (event.type() == QtCore.QEvent.KeyPress and event.key() == QtCore.Qt.Key_Menu):
+      if obj == self.ui.wptView:
+        self.wptContextMenuEvent(QtGui.QContextMenuEvent(event))
+      elif obj == self.ui.trkView:
+        self.trkContextMenuEvent(QtGui.QContextMenuEvent(event))
+      return True
+    else:
+      return super(GpxMainWindow, self).eventFilter(obj, event)
+
   def closeEvent(self, event):
     if self.projectChanged and len(TheDocument['GPXFile']) != 0:
       result = QtWidgets.QMessageBox.information(self, self.tr('Close GPX Viewer'),
@@ -121,67 +135,75 @@ class GpxMainWindow(QtWidgets.QMainWindow):
     TheConfig.save()
     super(GpxMainWindow, self).closeEvent(event)
 
-  def contextMenuEvent(self, event):
-    if self.ui.tabWidget.currentWidget() == self.ui.wptTab:
-      if self.ui.wptView.selectionModel().hasSelection():
-        actSkip = QtWidgets.QAction(self.tr('Skip points'), self)
-        actSkip.triggered.connect(self.skipPoints)
-        actMarker = QtWidgets.QAction(self.tr('Points with markers'), self)
-        actMarker.triggered.connect(self.markerPoints)
-        actCaption = QtWidgets.QAction(self.tr('Points with captions and markers'), self)
-        actCaption.triggered.connect(self.captionPoints)
-        actSplit = QtWidgets.QAction(self.tr('Points with splitting lines'), self)
-        actSplit.triggered.connect(self.splitLines)
-        actNeglect = QtWidgets.QAction(self.tr('Neglect previous distance'), self)
-        actNeglect.triggered.connect(self.neglectDistance)
-        actReset = QtWidgets.QAction(self.tr('Reset'), self)
-        actReset.triggered.connect(self.resetPoints)
-        actStyle = QtWidgets.QAction(QtGui.QIcon.fromTheme('configure', QtGui.QIcon(':/icons/configure.svg')), self.tr('Point style'), self)
-        actStyle.triggered.connect(self.pointStyle)
+  def wptContextMenuEvent(self, event):
+    if self.ui.wptView.selectionModel().hasSelection():
+      actSkip = QtWidgets.QAction(self.tr('Skip points'), self)
+      actSkip.triggered.connect(self.skipPoints)
+      actMarker = QtWidgets.QAction(self.tr('Points with markers'), self)
+      actMarker.triggered.connect(self.markerPoints)
+      actCaption = QtWidgets.QAction(self.tr('Points with captions and markers'), self)
+      actCaption.triggered.connect(self.captionPoints)
+      actSplit = QtWidgets.QAction(self.tr('Points with splitting lines'), self)
+      actSplit.triggered.connect(self.splitLines)
+      actNeglect = QtWidgets.QAction(self.tr('Neglect previous distance'), self)
+      actNeglect.triggered.connect(self.neglectDistance)
+      actReset = QtWidgets.QAction(self.tr('Reset'), self)
+      actReset.triggered.connect(self.resetPoints)
+      actShowMap = QtWidgets.QAction(self.tr('Show on Google maps'), self)
+      actShowMap.triggered.connect(self.showGoogleMaps)
+      actStyle = QtWidgets.QAction(QtGui.QIcon.fromTheme('configure', QtGui.QIcon(':/icons/configure.svg')), self.tr('Point style'), self)
+      actStyle.triggered.connect(self.pointStyle)
 
-        menu = QtWidgets.QMenu(self)
-        menu.addAction(actSkip)
-        menu.addAction(actMarker)
-        menu.addAction(actCaption)
-        menu.addSeparator()
-        menu.addAction(actSplit)
-        menu.addAction(actNeglect)
-        menu.addSeparator()
-        menu.addAction(actReset)
-        menu.addSeparator()
-        menu.addAction(actStyle)
-        menu.popup(event.globalPos())
-    else:
-      if self.ui.trkView.selectionModel().hasSelection():
-        actSkip = QtWidgets.QAction(self.tr('Skip tracks'), self)
-        actSkip.triggered.connect(self.skipTracks)
-        actReset = QtWidgets.QAction(self.tr('Reset'), self)
-        actReset.triggered.connect(self.resetTracks)
+      menu = QtWidgets.QMenu(self)
+      menu.addAction(actSkip)
+      menu.addAction(actMarker)
+      menu.addAction(actCaption)
+      menu.addSeparator()
+      menu.addAction(actSplit)
+      menu.addAction(actNeglect)
+      menu.addSeparator()
+      menu.addAction(actReset)
+      menu.addSeparator()
+      menu.addAction(actShowMap)
+      menu.addSeparator()
+      menu.addAction(actStyle)
+      menu.popup(QtGui.QCursor.pos())
+      event.accept()
 
-        menu = QtWidgets.QMenu(self)
-        menu.addAction(actSkip)
-        menu.addAction(actReset)
-        menu.popup(event.globalPos())
+  def trkContextMenuEvent(self, event):
+    if self.ui.trkView.selectionModel().hasSelection():
+      actSkip = QtWidgets.QAction(self.tr('Skip tracks'), self)
+      actSkip.triggered.connect(self.skipTracks)
+      actReset = QtWidgets.QAction(self.tr('Reset'), self)
+      actReset.triggered.connect(self.resetTracks)
 
-  def eventFilter(self, obj, event):
-    if event.type() == QtCore.QEvent.KeyPress and event.key() == QtCore.Qt.Key_Tab and event.modifiers() == QtCore.Qt.ControlModifier:
-      self.keyPressEvent(QtGui.QKeyEvent(event))
-      return True
-    else:
-      return super(GpxMainWindow, self).eventFilter(obj, event)
+      menu = QtWidgets.QMenu(self)
+      menu.addAction(actSkip)
+      menu.addAction(actReset)
+      menu.popup(QtGui.QCursor.pos())
+      event.accept()
 
   def keyPressEvent(self, event):
     if event.key() == QtCore.Qt.Key_F and event.modifiers() == QtCore.Qt.ControlModifier:
       self.filterLineEdit.setFocus()
       self.filterLineEdit.selectAll()
-    if event.key() == QtCore.Qt.Key_C and event.modifiers() == QtCore.Qt.ControlModifier:
+    elif event.key() == QtCore.Qt.Key_C and event.modifiers() == QtCore.Qt.ControlModifier:
       if self.ui.tabWidget.currentWidget() == self.ui.wptTab:
         TheDocument.wptmodel.copyToClipboard([i.data(gpx.IDRole) for i in self.ui.wptView.selectionModel().selectedRows()])
       else:
         TheDocument.trkmodel.copyToClipboard([i.row() for i in self.ui.trkView.selectionModel().selectedRows()])
-    if event.key() == QtCore.Qt.Key_Escape:
-      self.ui.wptView.setFocus()
-    if event.key() == QtCore.Qt.Key_Tab and event.modifiers() == QtCore.Qt.ControlModifier:
+    elif event.key() == QtCore.Qt.Key_Escape:
+      if self.ui.tabWidget.currentWidget() == self.ui.wptTab:
+        if self.ui.wptView.hasFocus():
+          self.ui.wptView.clearSelection()
+        else:
+          self.ui.wptView.setFocus()
+      else:
+        if self.ui.trkView.hasFocus():
+          self.ui.trkView.clearSelection()
+        else:
+          self.ui.trkView.setFocus()
+    elif event.key() == QtCore.Qt.Key_Tab and event.modifiers() == QtCore.Qt.ControlModifier:
       self.ui.tabWidget.setCurrentIndex(1 - self.ui.tabWidget.currentIndex())
     super(GpxMainWindow, self).keyPressEvent(event)
 
@@ -264,6 +286,11 @@ class GpxMainWindow(QtWidgets.QMainWindow):
     self.includefiltermodel.invalidateFilter()
     self.setProjectChanged(True)
 
+  def showGoogleMaps(self):
+    lat = TheDocument.wptmodel.index(self.ui.wptView.currentIndex().row(), gpx.LAT).data()
+    lon = TheDocument.wptmodel.index(self.ui.wptView.currentIndex().row(), gpx.LON).data()
+    subprocess.call('xdg-open ' + '"http://maps.google.com/maps?ll=' + lat + ',' + lon + '&t=h&q=' + lat + ',' + lon + '&z=17"', shell=True)
+
   def pointStyle(self):
     style = {}
     style.update(self.ui.wptView.selectionModel().selection().indexes()[0].data(gpx.MarkerRole))
@@ -330,10 +357,7 @@ class GpxMainWindow(QtWidgets.QMainWindow):
   def fileLoadGPXFile(self):
     filenames = QtWidgets.QFileDialog.getOpenFileNames(self, self.tr('Open GPX file'), TheConfig['MainWindow']['LoadGPXDirectory'],
                                                        self.tr('GPX XML (*.gpx);;All files (*)'))[0]
-    for f in filenames:
-      self.openGPXFile(f)
-    TheDocument.gpxparser.updatePoints()
-    self.updateTabs()
+    self.openGPXFiles(filenames)
 
   def fileSaveGPXFileAs(self):
     if TheDocument.wptmodel.rowCount() == len(TheDocument.wptmodel.getIndexesWithIncludeState(gpx.INC_SKIP)) and \
@@ -344,7 +368,7 @@ class GpxMainWindow(QtWidgets.QMainWindow):
     filename = QtWidgets.QFileDialog.getSaveFileName(self, self.tr('Save GPX file as'), TheConfig['MainWindow']['LoadGPXDirectory'],
                                                      self.tr('GPX XML (*.gpx);;All files (*)'))[0]
     if filename != '':
-      TheConfig['MainWindow']['LoadGPXDirectory'] = path.dirname(filename)
+      TheConfig['MainWindow']['LoadGPXDirectory'] = QtCore.QDir(filename).path()
       TheDocument.gpxparser.writeToFile(filename)
 
   def fileOpen(self):
@@ -363,7 +387,6 @@ class GpxMainWindow(QtWidgets.QMainWindow):
                                                      self.tr('GPX Viewer Projects (*.gpxv);;All files (*)'))[0]
     if filename != '':
       self.openGPXProject(filename)
-      self.updateTabs()
 
   def fileSave(self):
     if not self.projectSaved:
@@ -381,7 +404,7 @@ class GpxMainWindow(QtWidgets.QMainWindow):
       if filename != '':
         self.projectFile = filename
         self.projectSaved = True
-        TheConfig['MainWindow']['ProjectDirectory'] = path.dirname(self.projectFile)
+        TheConfig['MainWindow']['ProjectDirectory'] = QtCore.QDir(self.projectFile).path()
         TheDocument.saveFile(self.projectFile)
         self.setProjectChanged(False)
         self.updateTitleFilename(self.projectFile)
@@ -392,8 +415,14 @@ class GpxMainWindow(QtWidgets.QMainWindow):
       QtWidgets.QMessageBox.warning(self, self.tr('Save error'), self.tr('The project is empty.'))
       return False
 
+  def openGPXFiles(self, filenames):
+    for f in filenames:
+      self.openGPXFile(f)
+    TheDocument.gpxparser.updatePoints()
+    self.updateTabs()
+
   def openGPXFile(self, filename):
-    TheConfig['MainWindow']['LoadGPXDirectory'] = path.dirname(filename)
+    TheConfig['MainWindow']['LoadGPXDirectory'] = QtCore.QDir(filename).path()
     TheDocument['GPXFile'] += [filename]
     self.projectSaved = False
     try:
@@ -416,7 +445,8 @@ class GpxMainWindow(QtWidgets.QMainWindow):
       self.ui.trkView.resizeColumnsToContents()
       self.setProjectChanged(False)
       self.updateTitleFilename(self.projectFile)
-      TheConfig['MainWindow']['ProjectDirectory'] = path.dirname(self.projectFile)
+      self.updateTabs()
+      TheConfig['MainWindow']['ProjectDirectory'] = QtCore.QDir(self.projectFile).path()
     except gpx.GpxWarning as e:
       self.reset()
       QtWidgets.QMessageBox.warning(self, self.tr('File read error'), e.args[0])
@@ -458,7 +488,6 @@ class GpxMainWindow(QtWidgets.QMainWindow):
       QtWidgets.QMessageBox.warning(self, self.tr('Statistics error'), self.tr('Not enouph points.'))
       return
 
-    self.stat.updateStatistics()
     self.stat.show()
     self.stat.activateWindow()
 
@@ -507,6 +536,7 @@ class GpxMainWindow(QtWidgets.QMainWindow):
             TheConfig['MainWindow'].getboolean('ShowMarked'), TheConfig['MainWindow'].getboolean('ShowCaptioned')]
     filter = [gpx.INCSTATES[i] for i, m in enumerate(mask) if m]
     self.includefiltermodel.setFilterRegExp('|'.join([str(f) for f in filter]))
+    self.ui.wptView.resizeColumnsToContents()
 
   def updateTitleFilename(self, title=None):
     if title is not None:
