@@ -53,7 +53,7 @@ class WptModel(QtCore.QAbstractTableModel):
     return len(self.fields)
 
   def data(self, index, role=QtCore.Qt.DisplayRole):
-    if role == QtCore.Qt.DisplayRole:
+    if role == QtCore.Qt.DisplayRole or role == QtCore.Qt.EditRole:
       if index.column() == TIME and self.waypoints[index.row()][index.column()] != '':
         return str(self.waypoints[index.row()][index.column()] + timedelta(minutes=TheConfig['ProfileStyle'].getint('TimeZoneOffset')))
       else:
@@ -90,6 +90,23 @@ class WptModel(QtCore.QAbstractTableModel):
       return font
     return None
 
+  def setData(self, index, value, role):
+    if index.isValid() and role == QtCore.Qt.EditRole and value != self.waypoints[index.row()][NAME]:
+      self.waypoints[index.row()][NAME] = value
+      self.changedNames += [index.row()]
+      self.pointNames += [value]
+      self.dataChanged.emit(index, index)
+      self.namesChanged.emit(True)
+      return True
+    else:
+      return False
+
+  def flags(self, index):
+    if index.column() == NAME:
+      return super(WptModel, self).flags(index) | QtCore.Qt.ItemIsEditable
+    else:
+      return super(WptModel, self).flags(index)
+
   def headerData(self, section, orientation, role):
     if role == QtCore.Qt.DisplayRole:
       return self.fields[section] if orientation == QtCore.Qt.Horizontal else section + 1
@@ -125,6 +142,8 @@ class WptModel(QtCore.QAbstractTableModel):
     self.splitStates = []
     self.neglectStates = []
     self.pointStyles = []
+    self.changedNames = []
+    self.pointNames = []
     self.endResetModel()
 
   def setIncludeStates(self, IDs, state, update=True):
@@ -146,6 +165,8 @@ class WptModel(QtCore.QAbstractTableModel):
     for i in IDs:
       self.splitStates[i] = state
 
+  namesChanged = QtCore.pyqtSignal(bool)
+
 
 class TrkModel(QtCore.QAbstractTableModel):
   def __init__(self, parent=None):
@@ -250,6 +271,11 @@ class GpxParser(QtCore.QObject):
         point[TIME_DAYS] = ''
         point['ID'] = wptid
 
+        # Additional fields
+        point['CMT'] = p.findtext('{%(ns)s}cmt' % ns)
+        point['DESC'] = p.findtext('{%(ns)s}desc' % ns)
+        point['SYM'] = p.findtext('{%(ns)s}sym' % ns)
+
         self.wptmodel.beginInsertRows(QtCore.QModelIndex(), wptid, wptid)
         self.wptmodel.waypoints += [point]
         self.wptmodel.includeStates += [INC_DEFAULT]
@@ -431,15 +457,27 @@ class GpxParser(QtCore.QObject):
           maxlat = p[LAT]
         if p[LON] > maxlon:
           maxlon = p[LON]
-        el = ET.Element('name')
-        el.text = p[NAME]
-        element.append(el)
         el = ET.Element('ele')
         el.text = str(p[ALT])
         element.append(el)
         el = ET.Element('time')
         el.text = p[TIME].strftime('%Y-%m-%dT%H:%M:%SZ')
         element.append(el)
+        el = ET.Element('name')
+        el.text = p[NAME]
+        element.append(el)
+        if p['CMT'] is not None:
+          el = ET.Element('cmt')
+          el.text = p['CMT']
+          element.append(el)
+        if p['DESC'] is not None:
+          el = ET.Element('desc')
+          el.text = p['DESC']
+          element.append(el)
+        if p['SYM'] is not None:
+          el = ET.Element('sym')
+          el.text = p['SYM']
+          element.append(el)
 
     for track, s in zip(self.trkmodel.tracks, self.trkmodel.includeStates):
       if s != INC_SKIP:
@@ -475,19 +513,22 @@ class GpxParser(QtCore.QObject):
     el = ET.Element('bounds', attrib={'minlat': str(minlat), 'minlon': str(minlon), 'maxlat': str(maxlat), 'maxlon': str(maxlon)})
     metadata.append(el)
 
-    outgpx = ET.tostring(root, encoding='unicode')
+    outgpx = '<?xml version="1.0" encoding="UTF-8"?>\n' + ET.tostring(root, encoding='unicode') + '\n'
     outgpx = outgpx.replace('<metadata', '\n  <metadata')
     outgpx = outgpx.replace('</metadata', '\n  </metadata')
     outgpx = outgpx.replace('<wpt', '\n  <wpt')
     outgpx = outgpx.replace('<trk', '\n  <trk')
     outgpx = outgpx.replace('<bounds', '\n    <bounds')
-    outgpx = outgpx.replace('<name', '\n    <name')
     outgpx = outgpx.replace('<ele', '\n    <ele')
     outgpx = outgpx.replace('<time', '\n    <time')
+    outgpx = outgpx.replace('<name', '\n    <name')
+    outgpx = outgpx.replace('<cmt', '\n    <cmt')
+    outgpx = outgpx.replace('<desc', '\n    <desc')
+    outgpx = outgpx.replace('<sym', '\n    <sym')
     outgpx = outgpx.replace('</wpt', '\n  </wpt')
     outgpx = outgpx.replace('</trk', '\n  </trk')
     outgpx = outgpx.replace('</gpx', '\n</gpx')
-    with open(filename, 'w') as file:
+    with open(filename, 'w', encoding='utf-8') as file:
       file.write(outgpx)
 
   warningSent = QtCore.pyqtSignal(str, str)
